==> openjdk-16_16.0.1+9.orig.tar.xz: openjdk-16-16.0.1+9/test/hotspot/jtreg/vmTestbase/metaspace/flags/maxMetaspaceSize/TestMaxMetaspaceSize.java <==
/*
 * Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */


/*
 * @test
 * @key randomness
 *
 * @summary converted from VM Testbase metaspace/flags/maxMetaspaceSize.
 *
 * @library /vmTestbase /test/lib
 * @build metaspace.flags.maxMetaspaceSize.maxMetaspaceSize
 * @run driver metaspace.flags.maxMetaspaceSize.TestMaxMetaspaceSize
 */
package metaspace.flags.maxMetaspaceSize;

import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

public class TestMaxMetaspaceSize {
    public static void main(String[] args) throws Exception {
        ProcessBuilder pb =
            ProcessTools.createTestJvm("-XX:MaxMetaspaceSize=100m",
                                       maxMetaspaceSize.class.getName());
        OutputAnalyzer out = new OutputAnalyzer(pb.start());

        if (out.getExitValue() == 0) {
            // test passed
            return;
        } else {
            System.out.println("Non-zero exit value from child process. Could be OOM, which is OK");
            out.shouldContain("Out of Memory Error");
        }
    }
}

==> openjdk-17_17.0.16+8.orig.tar.xz: openjdk-17-17.0.16+8/test/hotspot/jtreg/vmTestbase/metaspace/flags/maxMetaspaceSize/TestMaxMetaspaceSize.java <==
/*
 * Copyright (c) 2017, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */


/*
 * @test
 * @key randomness
 *
 * @summary converted from VM Testbase metaspace/flags/maxMetaspaceSize.
 *
 * @library /vmTestbase /test/lib
 * @build metaspace.flags.maxMetaspaceSize.maxMetaspaceSize
 * @run driver metaspace.flags.maxMetaspaceSize.TestMaxMetaspaceSize
 */
package metaspace.flags.maxMetaspaceSize;

import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;

public class TestMaxMetaspaceSize {
    public static void main(String[] args) throws Exception {
        ProcessBuilder pb =
            ProcessTools.createTestJavaProcessBuilder("-XX:MaxMetaspaceSize=100m",
                                                      maxMetaspaceSize.class.getName());
        OutputAnalyzer out = new OutputAnalyzer(pb.start());

        if (out.getExitValue() == 0) {
            // test passed
            return;
        } else {
            System.out.println("Non-zero exit value from child process. Could be OOM, which is OK");
            out.shouldContain("Out of Memory Error");
        }
    }
}
